==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaGjzwsyqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 构（建）筑物所有权属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_gjzwsyq_ls"
)
public class BaGjzwsyqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String tdhysyqr;

    @XmlAttribute
    private float tdhysymj;

    @XmlAttribute
    @Nullable
    private Date tdhysyqssj;

    @XmlAttribute
    @Nullable
    private Date tdhysyjssj;

    @XmlAttribute
    private String gjzwlx;

    @XmlAttribute
    private String gjzwghyt;

    @XmlAttribute
    private float gjzwmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String gjzwpmt;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZl() {
        return zl;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public float getTdhysymj() {
        return tdhysymj;
    }

    public Date getTdhysyqssj() {
        return tdhysyqssj;
    }

    public Date getTdhysyjssj() {
        return tdhysyjssj;
    }

    public String getGjzwlx() {
        return gjzwlx;
    }

    public String getGjzwghyt() {
        return gjzwghyt;
    }

    public float getGjzwmj() {
        return gjzwmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getGjzwpmt() {
        return gjzwpmt;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public void setTdhysymj(float tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public void setTdhysyqssj(Date tdhysyqssj) {
        this.tdhysyqssj = tdhysyqssj;
    }

    public void setTdhysyjssj(Date tdhysyjssj) {
        this.tdhysyjssj = tdhysyjssj;
    }

    public void setGjzwlx(String gjzwlx) {
        this.gjzwlx = gjzwlx;
    }

    public void setGjzwghyt(String gjzwghyt) {
        this.gjzwghyt = gjzwghyt;
    }

    public void setGjzwmj(float gjzwmj) {
        this.gjzwmj = gjzwmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setGjzwpmt(String gjzwpmt) {
        this.gjzwpmt = gjzwpmt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}

==> realestate-supervise-common-1.1.0-20220818.055648-18-sources.jar: cn/gtmap/realestate/supervise/entity/BaGjzwsyqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 构（建）筑物所有权属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_gjzwsyq_ls"
)
public class BaGjzwsyqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String tdhysyqr;

    @XmlAttribute
    private float tdhysymj;

    @XmlAttribute
    @Nullable
    private Date tdhysyqssj;

    @XmlAttribute
    @Nullable
    private Date tdhysyjssj;

    @XmlAttribute
    private String gjzwlx;

    @XmlAttribute
    private String gjzwghyt;

    @XmlAttribute
    private float gjzwmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String gjzwpmt;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String tdhysyqx;

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getTdhysyqx() {
        return tdhysyqx;
    }

    public void setTdhysyqx(String tdhysyqx) {
        this.tdhysyqx = tdhysyqx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZl() {
        return zl;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public float getTdhysymj() {
        return tdhysymj;
    }

    public Date getTdhysyqssj() {
        return tdhysyqssj;
    }

    public Date getTdhysyjssj() {
        return tdhysyjssj;
    }

    public String getGjzwlx() {
        return gjzwlx;
    }

    public String getGjzwghyt() {
        return gjzwghyt;
    }

    public float getGjzwmj() {
        return gjzwmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getGjzwpmt() {
        return gjzwpmt;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public void setTdhysymj(float tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public void setTdhysyqssj(Date tdhysyqssj) {
        this.tdhysyqssj = tdhysyqssj;
    }

    public void setTdhysyjssj(Date tdhysyjssj) {
        this.tdhysyjssj = tdhysyjssj;
    }

    public void setGjzwlx(String gjzwlx) {
        this.gjzwlx = gjzwlx;
    }

    public void setGjzwghyt(String gjzwghyt) {
        this.gjzwghyt = gjzwghyt;
    }

    public void setGjzwmj(float gjzwmj) {
        this.gjzwmj = gjzwmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setGjzwpmt(String gjzwpmt) {
        this.gjzwpmt = gjzwpmt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}
